@@ -3,6 +3,8 @@
 
 #include <sarray/RangeIterator.h>
 
+namespace jags {
+
 /**
  * @short Mutable index that traverses a BUGS-language "for" loop
  *
@@ -26,5 +28,7 @@ public:
   Counter &next();
 };
 
+} /* namespace jags */
+
 #endif /* COUNTER_H_ */
 
