@@ -6,6 +6,8 @@
 
 #include <distribution/DistPtr.h>
 
+namespace jags {
+
 /**
  * @short Look-up table for Distribution objects
  *
@@ -19,6 +21,7 @@ class DistTab
     std::list<DistPtr> _dlist;
     DistPtr const _nulldist;
 public:
+    DistTab();
     /**
      * Inserts a dist into the table. 
      */
@@ -36,4 +39,6 @@ public:
     void erase(DistPtr const &dist);
 };
 
+} /* namespace jags */
+
 #endif /* DIST_TAB_H_ */
