@@ -3,6 +3,8 @@
 
 #include <function/Function.h>
 
+namespace jags {
+
 /**
  * @short Inverse link functions.
  *
@@ -35,4 +37,6 @@ public:
     virtual double grad(double eta) const = 0;
 };
 
+} /* namespace jags */
+
 #endif /* LINK_FUNCTION_H_ */
