@@ -4,6 +4,8 @@
 #include <graph/LogicalNode.h>
 #include <vector>
 
+namespace jags {
+
 class ScalarFunction;
 
 /**
@@ -21,7 +23,7 @@ public:
      * may be an inline operator in the BUGS language) and its
      * parameters.
      */
-    VSLogicalNode(ScalarFunction const *func,
+    VSLogicalNode(ScalarFunction const *func, unsigned int nchain,
 		  std::vector<Node const*> const &parameters);
     /**
      * Calculates the value of the node based on the parameters. 
@@ -31,7 +33,9 @@ public:
      * @see ScalarFunction#checkParameterValue.
      */
     bool checkParentValues(unsigned int chain) const;
-    DeterministicNode *clone(std::vector<Node const *> const &parents) const;
+    //DeterministicNode *clone(std::vector<Node const *> const &parents) const;
 };
 
+} /* namespace jags */
+
 #endif /* V_SCALAR_LOGICAL_NODE_H_ */
