@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000 The R Development Core Team
+ *  Copyright (C) 2000 The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 
 #include "nmath.h"
 
-double rchisq(double df, RNG *rng)
+double rchisq(double df, JRNG *rng)
 {
     if (!R_FINITE(df) || df < 0.0) ML_ERR_return_NAN;
 
