@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000--2008 The R Development Core Team
+ *  Copyright (C) 2000--2008 The R Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,12 +30,12 @@
 
 #include "nmath.h"
 
-double rexp(double scale, RNG *rng)
+double rexp(double scale, JRNG *rng)
 {
     if (!R_FINITE(scale) || scale <= 0.0) {
 	if(scale == 0.) return 0.;
 	/* else */
 	ML_ERR_return_NAN;
     }
-    return scale * exp_rand(rng);
+    return scale * exp_rand(rng); // --> in ./sexp.c
 }
