@@ -12,6 +12,8 @@ using std::vector;
 using std::map;
 using std::logic_error;
 
+namespace jags {
+
 MixtureNode * 
 MixtureFactory::getMixtureNode(vector<Node const *> const &index_nodes,
 			       MixMap const &mixmap, Model &model)
@@ -40,9 +42,11 @@ MixtureFactory::getMixtureNode(vector<Node const *> const &index_nodes,
             throw logic_error("Length mismatch in MixtureFactory::getMixtureNode");
         }
 	
-	MixtureNode *mix = new MixtureNode(index_nodes, mixmap);
+	MixtureNode *mix = new MixtureNode(index_nodes, model.nchain(), mixmap);
 	_mix_node_map[mpair] = mix;
 	model.addNode(mix);
 	return mix;
     }
 }
+
+} //namespace jags
