@@ -12,6 +12,8 @@ using std::vector;
 using std::string;
 using std::logic_error;
 
+namespace jags {
+
 static vector<unsigned int> mkDim(ArrayFunction const *func, 
 				  vector<Node const *> const &parents)
 {
@@ -20,20 +22,32 @@ static vector<unsigned int> mkDim(ArrayFunction const *func,
        parameters.
     */
 
-    vector<vector<unsigned int> > parameter_dims(parents.size());
-    for (unsigned int j = 0; j < parents.size(); ++j) {
-	parameter_dims[j] = parents[j]->dim();
+    unsigned long N = parents.size();
+    vector<vector<unsigned int> > dims(N);
+    vector<bool> fixed(N), discrete(N);
+    vector<double const *> values(N);
+    for (unsigned int j = 0; j < N; ++j) {
+	dims[j] = parents[j]->dim();
+	fixed[j] = parents[j]->isFixed();
+	values[j] = parents[j]->value(0);
+	discrete[j] = parents[j]->isDiscreteValued();
     }
     if (!func) {
 	throw logic_error("NULL function in ArrayLogicalNode constructor");
     }
-    if (!func->checkNPar(parameter_dims.size())) {
+    if (!checkNPar(func, dims.size())) {
 	throw FuncError(func, "Incorrect number of parameters");
     }
-    if (!func->checkParameterDim(parameter_dims)) {
+    if (!func->checkParameterDim(dims)) {
 	throw FuncError(func, "Non-conforming parameters");
     }
-    return func->dim(parameter_dims);
+    if (!func->checkParameterFixed(fixed)) {
+	throw FuncError(func, "Expected parameters with fixed values");
+    }
+    if (!func->checkParameterDiscrete(discrete)) {
+	throw FuncError(func, "Failed check for discrete-valued parameters");
+    }
+    return func->dim(dims, values);
 }
 
 static vector<vector<unsigned int> > const &
@@ -45,12 +59,13 @@ mkParameterDims(vector<Node const *> const &parameters) {
     return getUnique(dims);
 }
 
-ArrayLogicalNode::ArrayLogicalNode(ArrayFunction const *function, 
+ArrayLogicalNode::ArrayLogicalNode(ArrayFunction const *function,
+				   unsigned int nchain,
 				   vector<Node const *> const &parameters)
-    : LogicalNode(mkDim(function,parameters), parameters, function),
+    : LogicalNode(mkDim(function,parameters), nchain, parameters, function),
       _func(function), _dims(mkParameterDims(parameters))
 {
-    if (isObserved()) {
+    if (isFixed()) {
 	for (unsigned int ch = 0; ch < _nchain; ++ch) {
 	    deterministicSample(ch);
 	}
@@ -67,9 +82,12 @@ bool ArrayLogicalNode::checkParentValues(unsigned int chain) const
     return _func->checkParameterValue(_parameters[chain], _dims);
 }
 
+    /*
 DeterministicNode *
 ArrayLogicalNode::clone(vector<Node const*> const &parents) const
 {
     return new ArrayLogicalNode(_func, parents);
 }
-
+    */
+    
+} //namespace jags
