@@ -3,6 +3,7 @@
 
 #include <rng/RNGFactory.h>
 
+namespace jags {
 namespace base {
     
 /**
@@ -16,11 +17,12 @@ namespace base {
     public:
 	BaseRNGFactory();
 	~BaseRNGFactory();
+	void setSeed(unsigned int seed);
 	std::vector<RNG *> makeRNGs(unsigned int n);
 	RNG * makeRNG(std::string const &name);
 	std::string name() const;
     };
 
-}
+}}
 
 #endif /* BASE_RNG_FACTORY_H_ */
