@@ -2,6 +2,7 @@
 
 #include "RealSlicer.h"
 #include "DiscreteSlicer.h"
+#include "MSlicer.h"
 #include "SliceFactory.h"
 
 #include <sampler/MutableSampler.h>
@@ -19,12 +20,17 @@ namespace base {
     bool 
     SliceFactory::canSample(StochasticNode * node, Graph const &graph) const
     {
-        if (node->isDiscreteValued()) {
-            return DiscreteSlicer::canSample(node);
-        }
-        else {
-            return RealSlicer::canSample(node);
-        }
+	if (node->length() == 1) {
+	    if (node->isDiscreteValued()) {
+		return DiscreteSlicer::canSample(node);
+	    }
+	    else {
+		return RealSlicer::canSample(node);
+	    }
+	}
+	else {
+	    return MSlicer::canSample(node);
+	}
     }
 
     Sampler *SliceFactory::makeSampler(StochasticNode *snode,
@@ -35,17 +41,26 @@ namespace base {
 
 	SingletonGraphView *gv = new SingletonGraphView(snode, graph);
 
-	bool discrete = snode->isDiscreteValued();
-	for (unsigned int ch = 0; ch < nchain; ++ch) {
-	    if (discrete) {
-		methods[ch] = new DiscreteSlicer(gv, ch);
+	string name;
+	if (snode->length() == 1) {
+	    bool discrete = snode->isDiscreteValued();
+	    for (unsigned int ch = 0; ch < nchain; ++ch) {
+		if (discrete) {
+		    methods[ch] = new DiscreteSlicer(gv, ch);
+		}
+		else {
+		    methods[ch] = new RealSlicer(gv, ch);
+		}
 	    }
-	    else {
-		methods[ch] = new RealSlicer(gv, ch);
+	    name = discrete ? "base::DiscreteSlicer" : "base::RealSlicer";
+	}
+	else {
+	    for (unsigned int ch = 0; ch < nchain; ++ch) {
+		methods[ch] = new MSlicer(gv, ch);
 	    }
+	    name = "base::MSlicer";
 	}
 
-	string name = discrete ? "base::DiscreteSlicer" : "base::RealSlicer";
 	return new MutableSampler(gv, methods, name);
     }
 
