@@ -3,6 +3,7 @@
 
 #include <distribution/VectorDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -41,11 +42,11 @@ public:
     bool isDiscreteValued(std::vector<bool> const &mask) const;
     bool checkParameterLength(std::vector<unsigned int> const &lengths) const;
     unsigned int length(std::vector<unsigned int> const &lengths) const;
-    double KL(std::vector<double const *> const &par1,
-	      std::vector<double const *> const &par2,
+    double KL(std::vector<double const *> const &par0,
+	      std::vector<double const *> const &par1,
 	      std::vector<unsigned int> const &lengths) const;
 };
 
-}
+}}
 
 #endif /* DCAT_H_ */
