@@ -1,8 +1,9 @@
 #ifndef DEXP_H_
 #define DEXP_H_
 
-#include "RScalarDist.h"
+#include <distribution/RScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -27,10 +28,10 @@ class DExp : public RScalarDist {
    * Checks that lambda > 0
    */
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
-  double KL(std::vector<double const *> const &par1,
-	    std::vector<double const *> const &par2) const;
+  double KL(std::vector<double const *> const &par0,
+	    std::vector<double const *> const &par1) const;
 };
 
-}
+}}
 
 #endif /* DEXP_H_ */
