@@ -2,6 +2,7 @@
 #include "DNorm.h"
 
 #include <rng/TruncatedNormal.h>
+#include <util/nainf.h>
 
 #include <cmath>
 
@@ -13,6 +14,7 @@ using std::vector;
 #define SIGMA(par) (1/sqrt(*par[1]))
 #define TAU(par) (*par[1])
 
+namespace jags {
 namespace bugs {
 
 DNorm::DNorm()
@@ -57,6 +59,10 @@ double DNorm::randomSample(vector<double const *> const &par,
 {
     double mu = MU(par);
     double sigma = SIGMA(par);
+
+    //Fix non-finite boundaries: ilr-normal functions do not accept them
+    if (lower && *lower == JAGS_NEGINF) lower = 0;
+    if (upper && *upper == JAGS_POSINF) upper = 0;
     
     if (lower && upper) {
 	double left = (*lower - mu)/sigma;
@@ -77,14 +83,15 @@ double DNorm::randomSample(vector<double const *> const &par,
 }
 
 
-double DNorm::KL(vector<double const *> const &par0,
-		 vector<double const *> const &par1) const
-{
-    double mu0 = MU(par0), tau0 = TAU(par0);
-    double mu1 = MU(par1), tau1 = TAU(par1);
-
-    return ((mu0 - mu1) * (mu0 - mu1) * tau1 + tau1/tau0 - 1 + 
-	    log(tau0/tau1)) / 2;
-}
-
-}
+    double DNorm::KL(vector<double const *> const &par0,
+		     vector<double const *> const &par1) const
+	
+    {
+	double mu0 = MU(par0), tau0 = TAU(par0);
+	double mu1 = MU(par1), tau1 = TAU(par1);
+	
+	return ((mu0 - mu1) * (mu0 - mu1) * tau1 + tau1/tau0 - 1 + 
+		log(tau0/tau1)) / 2;
+    }
+    
+}}
