@@ -3,6 +3,7 @@
 
 #include <distribution/ScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -31,10 +32,10 @@ public:
     double u(std::vector<double const *> const &parameters) const;
     bool isSupportFixed(std::vector<bool> const &fixmask) const;
     unsigned int df() const;
-    double KL(std::vector<double const *> const &par1,
-	      std::vector<double const *> const &par2) const;
+    double KL(std::vector<double const *> const &par0,
+	      std::vector<double const *> const &par1) const;
 };
 
-}
+}}
 
 #endif /* DROUND_H_ */
