@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -22,8 +23,14 @@ public:
     IfElse ();
     double evaluate(std::vector<double const *> const &args) const;
     bool isDiscreteValued(std::vector<bool> const &mask) const;
+    bool isAdditive(std::vector<bool> const &mask, 
+		    std::vector<bool> const &fixed) const;
+    bool isScale(std::vector<bool> const &mask, 
+		 std::vector<bool> const &fixed) const;
+    bool isLinear(std::vector<bool> const &mask, 
+		  std::vector<bool> const &fixed) const;
 };
 
-}
+}}
 
 #endif /* IF_ELSE_H_ */
