@@ -3,6 +3,7 @@
 
 #include <function/ArrayFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -19,12 +20,13 @@ namespace bugs {
 		       std::vector<std::vector<unsigned int> > const &dims) 
 	    const;
 	std::vector<unsigned int> 
-	    dim(std::vector<std::vector<unsigned int> > const &args) const;
+	    dim(std::vector<std::vector<unsigned int> > const &args,
+		std::vector<double const *> const &values) const;
 	bool checkParameterDim(std::vector<std::vector<unsigned int> > const &dims) const;
 	bool checkParameterValue(std::vector<double const *> const &args,
 				 std::vector<std::vector<unsigned int> > const &dims) const;
     };
 
-}
+}}
 
 #endif /* INVERSE_H_ */
