@@ -8,6 +8,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace bugs {
 
     LogDet::LogDet ()
@@ -28,7 +29,8 @@ namespace bugs {
     }
 
     vector<unsigned int>
-    LogDet::dim(vector<vector<unsigned int> > const &dims) const
+    LogDet::dim(vector<vector<unsigned int> > const &dims,
+		vector<double const *> const &values) const
     {
 	return vector<unsigned int>(1,1);
     }
@@ -41,5 +43,4 @@ namespace bugs {
 	return check_symmetry(args[0], dims[0][0]);
     }
 
-}
-
+}}
