@@ -1,8 +1,9 @@
 #ifndef FUNC_MEAN_H_
 #define FUNC_MEAN_H_
 
-#include <function/VectorFunction.h>
+#include <function/ScalarVectorFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -13,16 +14,16 @@ namespace bugs {
      * y <- mean(x[])
      * </pre>
      */
-    class Mean : public VectorFunction
+    class Mean : public ScalarVectorFunction
     {
     public:
 	Mean ();
-	void evaluate(double *x, std::vector<double const *> const &args,
-		      std::vector<unsigned int> const &dims) const;
-	bool checkParameterLength (std::vector<unsigned int> const &len) const;
+	double scalarEval(std::vector<double const *> const &args,
+			  std::vector<unsigned int> const &dims) const;
 	bool isScale(std::vector<bool> const &mask,
 		     std::vector<bool> const &fix) const;
     };
-}
+
+}}
 
 #endif /* FUNC_MEAN_H_ */
