@@ -3,6 +3,7 @@
 
 #include <function/VectorFunction.h>
 
+namespace jags {
 namespace bugs {
 
     /**
@@ -25,10 +26,11 @@ namespace bugs {
 	void evaluate(double *value, 
 		      std::vector<double const *> const &args,
 		      std::vector<unsigned int> const &lengths) const;
-	unsigned int length(std::vector<unsigned int> const &args) const;
+	unsigned int length(std::vector<unsigned int> const &parlengths,
+			    std::vector<double const *> const &parvalues) const;
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
     };
     
-}
+}}
 
 #endif /* FUNC_RANK_H_ */
