@@ -4,10 +4,12 @@
 #include <algorithm>
 
 #include <util/dim.h>
+#include <util/logical.h>
 
 using std::vector;
 using std::sort;
 
+namespace jags {
 namespace bugs {
 
     Sort::Sort ()
@@ -24,21 +26,15 @@ namespace bugs {
 	sort(value, value + lengths[0]);
     }
 
-    unsigned int Sort::length (vector<unsigned int> const &parlengths) const
+    unsigned int Sort::length (vector<unsigned int> const &parlengths,
+			       vector<double const *> const &parvalues) const
     {
 	return parlengths[0];
     }
 
     bool Sort::isDiscreteValued(vector<bool> const &mask) const
     {
-#ifdef _RWSTD_NO_CLASS_PARTIAL_SPEC
-//workaround for Solaris libCstd
-        int n = 0; 
-        count(mask.begin(), mask.end(), false, n);
-        return n == 0;
-#else
-	return count(mask.begin(), mask.end(), false) == 0;
-#endif
+	return allTrue(mask);
     }
 
-}
+}}
