@@ -3,6 +3,7 @@
 
 #include <function/ScalarFunction.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -19,6 +20,6 @@ namespace bugs {
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
     };
 
-}
+}}
 
 #endif /* FUNC_TRUNC_H_ */
