@@ -1,6 +1,9 @@
 #ifndef MATRIX_H_
 #define MATRIX_H_
 
+namespace jags {
+namespace bugs {
+
 /**
  * Inverts a general square matrix using the LAPACK routine DGESV
  *
@@ -27,6 +30,16 @@ bool inverse (double *X, double const *A, int n);
  */
 bool inverse_spd (double *X, double const *A, int n);
 
+/**
+ * Checks whether a symmetric matrix is positive definite
+ *
+ * @param A pointer to array containing the values of the matrix. Only
+ * the lower triangle (in column-major order) is used.
+ *
+ * @param n number or rows or columns in the matrix
+ */
+bool check_symmetric_ispd(double const *a, int n);
+
 /**
  * Log determinant of a symmetric positive definite matrix
  *
@@ -48,4 +61,6 @@ double logdet(double const *A, int n);
  */
 bool check_symmetry(double const *X, unsigned int n, double tol=1e-7);
 
+}}
+
 #endif /* MATRIX_H_ */
