@@ -3,6 +3,10 @@
 
 #include "ConjugateMethod.h"
 
+namespace jags {
+
+    class Graph;
+
 namespace bugs {
 
 /**
@@ -16,12 +20,11 @@ namespace bugs {
  */
 class ConjugateBeta : public ConjugateMethod {
 public:
-    ConjugateBeta(GraphView const *gv);
+    ConjugateBeta(SingletonGraphView const *gv);
     void update(unsigned int chain, RNG *rng) const;
     static bool canSample(StochasticNode *snode, Graph const &graph);
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* CONJUGATE_BETA_H_ */
