@@ -3,6 +3,10 @@
 
 #include "ConjugateMethod.h"
 
+namespace jags {
+    
+    class Graph;
+
 namespace bugs {
 
 /**
@@ -22,13 +26,12 @@ class ConjugateMNormal : public ConjugateMethod {
   double *_betas;
   const unsigned int _length_betas;
  public:
-  ConjugateMNormal(GraphView const *gv);
+  ConjugateMNormal(SingletonGraphView const *gv);
   ~ConjugateMNormal();
   void update(unsigned int chain, RNG *rng) const;
   static bool canSample(StochasticNode *snode, Graph const &graph);
-  std::string name() const;
 };
 
-}
+}}
 
 #endif /* CONJUGATE_M_NORMAL_H_ */
