@@ -3,6 +3,10 @@
 
 #include "ConjugateMethod.h"
 
+namespace jags {
+
+    class Graph;
+
 namespace bugs {
 
 /**
@@ -17,13 +21,12 @@ class ConjugateNormal : public ConjugateMethod {
     double *_betas;
     unsigned long _length_betas;
 public:
-    ConjugateNormal(GraphView const *gv);
+    ConjugateNormal(SingletonGraphView const *gv);
     ~ConjugateNormal();
     void update(unsigned int chain, RNG *rng) const;
     static bool canSample(StochasticNode *snode, Graph const &graph);
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* CONJUGATE_NORMAL_H_ */
