@@ -8,7 +8,7 @@
 #include <graph/StochasticNode.h>
 #include <graph/MixtureNode.h>
 #include <sampler/Linear.h>
-#include <sampler/GraphView.h>
+#include <sampler/SingletonGraphView.h>
 
 #include <set>
 #include <vector>
@@ -23,6 +23,9 @@ using std::sqrt;
 using std::string;
 using std::copy;
 
+namespace jags {
+namespace bugs {
+
 static inline double getPrecision0(StochasticNode const *snode, 
 				   unsigned int chain)
 {
@@ -32,8 +35,6 @@ static inline double getPrecision0(StochasticNode const *snode,
     return snode->parents()[1]->value(chain)[0];
 }
 
-namespace bugs {
-
 bool ConjugateWishart::canSample(StochasticNode *snode, Graph const &graph)
 {
     if (getDist(snode) != WISH)
@@ -42,8 +43,8 @@ bool ConjugateWishart::canSample(StochasticNode *snode, Graph const &graph)
     if (isBounded(snode))
 	return false;
   
-    GraphView gv(snode, graph);
-    vector<StochasticNode const*> const &schild = gv.stochasticChildren();
+    SingletonGraphView gv(snode, graph);
+    vector<StochasticNode *> const &schild = gv.stochasticChildren();
 
     // Check stochastic children
     for (unsigned int i = 0; i < schild.size(); ++i) {
@@ -78,18 +79,18 @@ bool ConjugateWishart::canSample(StochasticNode *snode, Graph const &graph)
     return true;
 }
 
-ConjugateWishart::ConjugateWishart(GraphView const *gv)
+ConjugateWishart::ConjugateWishart(SingletonGraphView const *gv)
     : ConjugateMethod(gv)
 {}
 
 void 
 ConjugateWishart::update(unsigned int chain, RNG *rng) const
 {
-    vector<StochasticNode const*> const &stoch_children = 
+    vector<StochasticNode *> const &stoch_children = 
 	_gv->stochasticChildren();
     unsigned int nchildren = stoch_children.size();
 
-    vector<Node const *> const &param = _gv->nodes()[0]->parents();  
+    vector<Node const *> const &param = _gv->node()->parents();  
 
     double df = *param[1]->value(chain);
     double const *Rprior = param[0]->value(chain);
@@ -111,7 +112,7 @@ ConjugateWishart::update(unsigned int chain, RNG *rng) const
 	    precision0[i] = getPrecision0(stoch_children[i], chain);
 	}
 	//Double the current value
-	double const *x = _gv->nodes()[0]->value(chain);
+	double const *x = _gv->node()->value(chain);
 	vector<double> x2(N);
 	for (int j = 0; j < N; ++j) {
 	    x2[j] = 2 * x[j];
@@ -145,9 +146,4 @@ ConjugateWishart::update(unsigned int chain, RNG *rng) const
     _gv->setValue(xnew, chain);
 }
 
-string ConjugateWishart::name() const
-{
-    return "ConjugateWishart";
-}
-
-}
+}}
