@@ -3,6 +3,7 @@
 
 #include <sampler/SamplerFactory.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -11,13 +12,13 @@ namespace bugs {
 class DSumFactory : public SamplerFactory
 {
 public:
-    std::vector<Sampler*> makeSamplers(std::set<StochasticNode*> const &nodes, 
+    std::vector<Sampler*> makeSamplers(std::list<StochasticNode*> const &nodes, 
 				       Graph const &graph) const;
-    Sampler * makeSampler(std::set<StochasticNode*> const &nodes, 
+    Sampler * makeSampler(std::list<StochasticNode*> const &nodes, 
 			  Graph const &graph) const;
     std::string name() const;
 };
 
-}
+}}
 
 #endif /* DSUM_FACTORY_H_ */
