@@ -8,6 +8,7 @@
 class StochasticNode;
 class GraphView;
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -19,9 +20,8 @@ public:
     RealDSum(GraphView const *gv, unsigned int chain);
     void step(std::vector<double> &value, unsigned int nrow, 
 	      unsigned int ncol, double s, RNG *rng) const;
-    std::string name() const;
 };
 
-}
+}}
 
 #endif /* REAL_DSUM_H_ */
