@@ -3,16 +3,19 @@
 
 #include "ConjugateMethod.h"
 
+namespace jags {
+
+    class Graph;
+
 namespace bugs {
 
     class ShiftedCount : public ConjugateMethod {
     public:
-	ShiftedCount(GraphView const *gv);
+	ShiftedCount(SingletonGraphView const *gv);
 	static bool canSample(StochasticNode *snode, Graph const &graph);
 	void update(unsigned int chain, RNG *rng) const;
-	std::string name() const;
     };
 
-}
+}}
 
 #endif /* SHIFTED_COUNT_H_ */
